@@ -185,7 +185,7 @@ use strict;
 
 use Carp qw(croak);
 
-our $VERSION = "0.004";
+our $VERSION = "0.005";
 
 use parent "Exporter";
 our @EXPORT_OK = qw(
@@ -254,12 +254,13 @@ The width, in bits, of the native integer data types.
 # signed integer representation.
 BEGIN {
 	use integer;
-	my $natint_bits = 1;
+	my $bit_count = 1;
 	my $test_bit = 1;
 	while($test_bit > 0) {
-		$natint_bits += 1;
+		$bit_count += 1;
 		$test_bit <<= 1;
 	}
+	my $natint_bits = $bit_count;
 	*natint_bits = sub () { $natint_bits };
 }
 
@@ -1407,7 +1408,7 @@ Andrew Main (Zefram) <zefram@fysh.org>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2007, 2010 Andrew Main (Zefram) <zefram@fysh.org>
+Copyright (C) 2007, 2010, 2015 Andrew Main (Zefram) <zefram@fysh.org>
 
 =head1 LICENSE
 
